==> heptapod-rails-0.32.1.tar.gz: heptapod-rails-0.32.1/scripts/heptapod_knapsack.sh <==
#!/bin/sh

# this script has to be run from the root of the Rails application

set -e

if test -z "$HEPTAPOD_RSPEC_SCOPE"; then
    HEPTAPOD_RSPEC_SCOPE=regular
fi

if test -n "$CI_NODE_TOTAL"; then
    HEPTAPOD_KNAPSACK_SHARDED="yes"
else
    HEPTAPOD_KNAPSACK_SHARDED="no"
fi

set -u

# set these environment variables to something relevant for your run
#export CI_NODE_TOTAL=2
#export CI_NODE_INDEX=0

# WARNING: This weird absence of indentation below in double quoted split
# string is the only layout that works.
# Reasonable-looking indentation would give:
#     lib/gitlab,: not found

if [ "$HEPTAPOD_RSPEC_SCOPE" = "extended" ]; then
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"helpers/storage_helper,"\
"helpers/emails_helper,"\
"lib/gitlab,"\
"lib/gitlab/*,"\
"lib/gitlab/**/*,"\
"lib/heptapod,"\
"lib/heptapod/*,"\
"lib/heptapod/**/*,"\
"mailers/*,"\
"mailers/emails/*,"\
"migrations/force_notes_rerender,"\
"models/*,"\
"models/**/*,"\
"presenters/*,"\
"requests/api/*,"\
"requests/api/**/*,"\
"requests/*,"\
"routing/git_http_routing,"\
"services/*,"\
"services/**/*,"\
"workers/*,"\
"workers/**/*,"\
"helpers/application_settings_helper,"\
"helpers/vcs_type_helper}"\
"_spec.rb"
elif [ "$HEPTAPOD_RSPEC_SCOPE" = "wip" ]; then
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"requests/api/*,"\
"requests/api/**/*}"\
"_spec.rb"
else
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"helpers/application_settings_helper,"\
"helpers/vcs_type_helper,"\
"helpers/storage_helper,"\
"helpers/emails_helper,"\
"lib/gitlab,"\
"lib/gitlab/database/*,"\
"lib/gitlab/mercurial/*,"\
"lib/gitlab/*_access*,"\
"lib/gitlab/git/*,"\
"lib/gitlab/import_export/*,"\
"lib/gitlab/workhorse,"\
"lib/heptapod,"\
"lib/heptapod/*,"\
"lib/heptapod/**/*,"\
"mailers/emails/pipelines,"\
"mailers/notify,"\
"migrations/force_notes_rerender,"\
"models/application_setting,"\
"models/ci/job_*,"\
"models/ci/pipeline*,"\
"models/compare,"\
"models/commit_*,"\
"models/merge_request,"\
"models/merge_request_*,"\
"models/note,"\
"models/*_note,"\
"models/project_hg*,"\
"models/user,"\
"models/*wiki*,"\
"presenters/project,"\
"requests/api/api,"\
"requests/api/heptapod_version,"\
"requests/api/projects,"\
"requests/api/settings,"\
"requests/git_http,"\
"requests/api/internal/base,"\
"requests/openid_connect,"\
"services/import/validate_remote_git_endpoint_service,"\
"services/projects/update_remote_mirror_service,"\
"services/projects/create_service,"\
"services/projects/hashed_storage/*,"\
"workers/every_sidekiq_worker,"\
"workers/post_receive}"\
"_spec.rb"
fi

echo "Running tests with $0."
echo "KNAPSACK_TEST_FILE_PATTERN: ${KNAPSACK_TEST_FILE_PATTERN}"

export KNAPSACK_TEST_FILE_PATTERN
export KNAPSACK_REPORT_PATH="knapsack/rspec.json"
if knapsack rspec "-Ispec --color --format d --tag ~quarantine --tag ~geo --tag ~level:migration"; then
    HEPTAPOD_KNAPSACK_RESULT=success
else
    HEPTAPOD_KNAPSACK_RESULT=failed
fi

if [ "$HEPTAPOD_KNAPSACK_SHARDED" = "yes" ]; then
    KNAPSACK_SHARD_REPORT_PATH=knapsack/rspec-${CI_NODE_INDEX}-of-${CI_NODE_TOTAL}.json
    echo "Moving new Knapsack timings to shard-specific $KNAPSACK_SHARD_REPORT_PATH"
    mv $KNAPSACK_REPORT_PATH $KNAPSACK_SHARD_REPORT_PATH
    HGPLAIN= hg revert -q $KNAPSACK_REPORT_PATH || /bin/true
fi

test "$HEPTAPOD_KNAPSACK_RESULT" = "success"

==> heptapod-rails-0.36.1.tar.gz: heptapod-rails-0.36.1/scripts/heptapod_knapsack.sh <==
#!/bin/sh

# this script has to be run from the root of the Rails application

set -e

if test -z "$HEPTAPOD_RSPEC_SCOPE"; then
    HEPTAPOD_RSPEC_SCOPE=regular
fi

if test -n "$CI_NODE_TOTAL"; then
    HEPTAPOD_KNAPSACK_SHARDED="yes"
else
    HEPTAPOD_KNAPSACK_SHARDED="no"
fi

if test -n "$RSPEC_SEED"; then
    SEED_ARGS="--seed ${RSPEC_SEED}"
else
    SEED_ARGS=""
fi

set -u

# set these environment variables to something relevant for your run
#export CI_NODE_TOTAL=2
#export CI_NODE_INDEX=0

# WARNING: This weird absence of indentation below in double quoted split
# string is the only layout that works.
# Reasonable-looking indentation would give:
#     lib/gitlab,: not found

if [ "$HEPTAPOD_RSPEC_SCOPE" = "extended" ]; then
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"helpers/storage_helper,"\
"helpers/emails_helper,"\
"lib/banzai/filter/references/*,"\
"lib/gitlab,"\
"lib/gitlab/*,"\
"lib/gitlab/**/*,"\
"lib/heptapod,"\
"lib/heptapod/*,"\
"lib/heptapod/**/*,"\
"mailers/*,"\
"mailers/emails/*,"\
"migrations/force_notes_rerender,"\
"models/*,"\
"models/**/*,"\
"presenters/*,"\
"requests/api/*,"\
"requests/api/**/*,"\
"requests/*,"\
"routing/git_http_routing,"\
"services/*,"\
"services/**/*,"\
"workers/*,"\
"workers/**/*,"\
"helpers/application_settings_helper,"\
"helpers/vcs_type_helper}"\
"_spec.rb"
elif [ "$HEPTAPOD_RSPEC_SCOPE" = "wip" ]; then
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"requests/api/*,"\
"requests/api/**/*}"\
"_spec.rb"
else
    KNAPSACK_TEST_FILE_PATTERN="spec/{"\
"helpers/application_settings_helper,"\
"helpers/vcs_type_helper,"\
"helpers/storage_helper,"\
"helpers/emails_helper,"\
"lib/banzai/filter/references/*,"\
"lib/gitlab,"\
"lib/gitlab/database/*,"\
"lib/gitlab/mercurial,"\
"lib/gitlab/mercurial/*,"\
"lib/gitlab/*_access*,"\
"lib/gitlab/git/*,"\
"lib/gitlab/import_export/*,"\
"lib/gitlab/workhorse,"\
"lib/heptapod,"\
"lib/heptapod/*,"\
"lib/heptapod/**/*,"\
"mailers/emails/pipelines,"\
"mailers/notify,"\
"migrations/force_notes_rerender,"\
"models/application_setting,"\
"models/ci/job_*,"\
"models/ci/pipeline*,"\
"models/blob_viewer/*,"\
"models/compare,"\
"models/commit_*,"\
"models/merge_request,"\
"models/merge_request_*,"\
"models/note,"\
"models/*_note,"\
"models/project_hg*,"\
"models/user,"\
"models/*wiki*,"\
"presenters/project,"\
"requests/api/api,"\
"requests/api/heptapod_version,"\
"requests/api/projects,"\
"requests/api/settings,"\
"requests/git_http,"\
"requests/api/internal/base,"\
"requests/openid_connect,"\
"services/import/validate_remote_git_endpoint_service,"\
"services/projects/update_remote_mirror_service,"\
"services/projects/create_service,"\
"services/projects/hashed_storage/*,"\
"workers/every_sidekiq_worker,"\
"workers/post_receive}"\
"_spec.rb"
fi

echo "Running tests with $0."
echo "KNAPSACK_TEST_FILE_PATTERN: ${KNAPSACK_TEST_FILE_PATTERN}"

export KNAPSACK_TEST_FILE_PATTERN
export KNAPSACK_REPORT_PATH="knapsack/rspec.json"
if knapsack rspec "-Ispec ${SEED_ARGS} --color --format d --tag ~quarantine --tag ~geo --tag ~level:migration"; then
    HEPTAPOD_KNAPSACK_RESULT=success
else
    HEPTAPOD_KNAPSACK_RESULT=failed
fi

if [ "$HEPTAPOD_KNAPSACK_SHARDED" = "yes" ]; then
    KNAPSACK_SHARD_REPORT_PATH=knapsack/rspec-${CI_NODE_INDEX}-of-${CI_NODE_TOTAL}.json
    echo "Moving new Knapsack timings to shard-specific $KNAPSACK_SHARD_REPORT_PATH"
    mv $KNAPSACK_REPORT_PATH $KNAPSACK_SHARD_REPORT_PATH
    HGPLAIN= hg revert -q $KNAPSACK_REPORT_PATH || /bin/true
fi

test "$HEPTAPOD_KNAPSACK_RESULT" = "success"
